<?php
/**
 * 2007-2015 PrestaShop
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License (AFL 3.0)
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://opensource.org/licenses/afl-3.0.php
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to http://www.prestashop.com for more information.
 *
 *  @author    PrestaShop SA <contact@prestashop.com>
 *  @copyright 2007-2015 PrestaShop SA
 *  @version	Release: $Revision: 17142 $
 *  @license   http://opensource.org/licenses/afl-3.0.php  Academic Free License (AFL 3.0)
 *  International Registered Trademark & Property of PrestaShop SA
 */

if (!defined('_PS_VERSION_'))
	exit;

class Fbtrackingpixel extends Module
{

	public function __construct()
	{
		$this->name = 'fbtrackingpixel';
		$this->tab = 'advertising_marketing';
		$this->version = '1.0.0';
		$this->author = 'dh42';
		$this->need_instance = 1;

		$this->bootstrap = true;
		parent::__construct();

		$this->displayName = $this->l('Facebook Tracking Pixel');
		$this->description = $this->l('Track Facebook Ad conversions easily');


	}

	public function install()
	{
		Configuration::updateValue('FB_TRACKING_PIXEL_ID', null);

		include(dirname(__FILE__).'/sql/install.php');

		return parent::install() &&
		$this->registerHook('header') &&
		$this->registerHook('backOfficeHeader');
	}

	public function uninstall()
	{

		include(dirname(__FILE__).'/sql/uninstall.php');

		return parent::uninstall();
	}

	/**
	 * Load the configuration form
	 */
	public function getContent()
	{
		/**
		 * If values have been submitted in the form, process.
		 */
		if (((bool)Tools::isSubmit('submitFbtrackingpixelModule')) == true) {
			$this->postProcess();
		}

		$this->context->smarty->assign(array(
			'module_dir' => $this->_path,
			'FB_TRACKING_PIXEL_ID' => Configuration::get('FB_TRACKING_PIXEL_ID')
		));

		$output = $this->context->smarty->fetch($this->local_path.'views/templates/admin/configure.tpl');

		return $output.$this->renderForm();
	}

	/**
	 * Create the form that will be displayed in the configuration of your module.
	 */
	protected function renderForm()
	{
		$helper = new HelperForm();

		$helper->show_toolbar = false;
		$helper->table = $this->table;
		$helper->module = $this;
		$helper->default_form_language = $this->context->language->id;
		$helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG', 0);

		$helper->identifier = $this->identifier;
		$helper->submit_action = 'submitFbtrackingpixelModule';
		$helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false)
			.'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
		$helper->token = Tools::getAdminTokenLite('AdminModules');

		$helper->tpl_vars = array(
			'fields_value' => $this->getConfigFormValues(), /* Add values for your inputs */
			'languages' => $this->context->controller->getLanguages(),
			'id_language' => $this->context->language->id,
		);

		return $helper->generateForm(array($this->getConfigForm()));
	}

	/**
	 * Create the structure of your form.
	 */
	protected function getConfigForm()
	{
		return array(
			'form' => array(
				'legend' => array(
					'title' => $this->l('Settings'),
					'icon' => 'icon-cogs',
				),
				'input' => array(

					array(
						'col' => 4,
						'type' => 'text',
						'prefix' => '<i class="icon icon-key"></i>',
						'desc' => $this->l('Enter a valid Facebook Pixel Id'),
						'name' => 'FB_TRACKING_PIXEL_ID',
						'label' => $this->l('Add your Facebook Conversion Tracking ID'),
					)
				),
				'submit' => array(
					'title' => $this->l('Save'),
				),
			),
		);
	}

	/**
	 * Set values for the inputs.
	 */
	protected function getConfigFormValues()
	{
		return array(
			'FB_TRACKING_PIXEL_ID' => Configuration::get('FB_TRACKING_PIXEL_ID'),
		);
	}

	/**
	 * Save form data.
	 */
	protected function postProcess()
	{
		$form_values = $this->getConfigFormValues();

		foreach (array_keys($form_values) as $key) {
			Configuration::updateValue($key, Tools::getValue($key));
		}
	}

	/**
	 * Add the CSS & JavaScript files you want to be loaded in the BO.
	 */
	public function hookBackOfficeHeader()
	{
		if (Tools::getValue('module_name') == $this->name) {
		}
	}

	/**
	 * Add the CSS & JavaScript files you want to be added on the FO.
	 */
	public function hookHeader()
	{
		if (Tools::getValue('controller') == 'orderconfirmation') {
			$order = new Order(Tools::getValue('id_order'));
			$currency = new Currency($order->id_currency);

			$this->context->smarty->assign(
				array(
					'FB_TRACKING_PIXEL_ID' => Configuration::get('FB_TRACKING_PIXEL_ID'),
					'CURRENCY' => $currency->iso_code,
					'TOTAL_ORDER' => $order->getOrdersTotalPaid(),
					'LANG' => $this->context->language->iso_code
				)
			);

			return $this->display(__FILE__, 'fbtrackingpixel.tpl');
		}
	}


}